==> php82-nextcloud-28.0.2.tgz: share/nextcloud/apps/files_external/l10n/es_AR.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Conceder acceso",
    "Error configuring OAuth1" : "Se presentó un error al configurar OAuth1",
    "Please provide a valid app key and secret." : "Favor de proporcionar una llave de aplicación y secreto válidos.",
    "Error configuring OAuth2" : "Se presentó un error al configurar OAuth2",
    "Generate keys" : "Generar llaves",
    "Error generating key pair" : "Se presentó un error al generar el juego de llaves",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilidad con codificación Mac NFD (lenta)",
    "Enable encryption" : "Habilitar encripción",
    "Enable previews" : "Habilitar vistas previas",
    "Enable sharing" : "Habilitar compartir",
    "Check for changes" : "Verificar si hay cambios",
    "Never" : "Nunca",
    "Once every direct access" : "Una vez cada acceso directo",
    "Read only" : "Solo lectura",
    "Disconnect" : "Desconectar",
    "Admin defined" : "Administrador definido",
    "Saved" : "Guardado",
    "Save" : "Guardar",
    "Storage with ID \"%d\" not found" : "El almacenamiento con ID \"%d\" no fue encontrado",
    "Invalid backend or authentication mechanism class" : "Backend o clase de mecanismo de autenticación inválido ",
    "Invalid mount point" : "Punto de montaje inválido",
    "Objectstore forbidden" : "Objectstore prohibido",
    "Invalid storage backend \"%s\"" : "Almacenamiento de backend \"%s\" inválido ",
    "Not permitted to use backend \"%s\"" : "No está permitido usar el backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "No está permitido el uso del mecanismo de autenticación \"%s\"",
    "Unsatisfied backend parameters" : "Parametros del backend no satisfechos",
    "Unsatisfied authentication mechanism parameters" : "Parametros no satisfechos del mecanismo de autenticación",
    "Insufficient data: %s" : "Datos insuficientes: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "El almacenamiento con ID \"%d\" no puede ser editado por el usuario",
    "Access key" : "Llave de acceso",
    "Secret key" : "Llave secreta",
    "Builtin" : "Integrado",
    "None" : "Ninguno",
    "OAuth1" : "OAuth1",
    "App key" : "Llave de la aplicación",
    "App secret" : "Secreto de la aplicación",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID del cliente",
    "Client secret" : "Secreto del cliente",
    "Username" : "Nombre de usuario",
    "Password" : "Contraseña",
    "Tenant name" : "¡No se encontraron archivos en su búsqueda que hayan sido modificados\n\n en los últimos 7 días! ",
    "Identity endpoint URL" : "URL del punto de enlace de Identidad",
    "Domain" : "Dominio",
    "Rackspace" : "Rackspace",
    "API key" : "Llave de API",
    "Global credentials" : "Credenciales globales",
    "Log-in credentials, save in database" : "Credenciales de inicio de sesión, guardar en la base de datos",
    "Username and password" : "Nombre de usuario y contraseña",
    "Log-in credentials, save in session" : "Credenciales de inicio de sesión, guardar en la sesión",
    "User entered, store in database" : "Usuario ingresado, almacenar en la base de datos",
    "RSA public key" : "Llave pública RSA",
    "Public key" : "Llave pública",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nombre del servidor",
    "Port" : "Puerto",
    "Region" : "Región",
    "Enable SSL" : "Habilitar SSL",
    "Enable Path Style" : "Habilitar Estilo de Ruta",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subcarpeta remota",
    "Secure https://" : "https:// seguro",
    "FTP" : "FTP",
    "Host" : "Servidor",
    "Secure ftps://" : "ftps:// seguro",
    "Local" : "Local",
    "Location" : "Ubicación",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Raíz",
    "SFTP with secret key login" : "Inicio de sesión SFTP con llave secreta",
    "Share" : "Compartir",
    "Show hidden files" : "Mostrar archivos ocultos",
    "Username as share" : "Nombre de usuario como elemento compartido",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nombre del servicio",
    "Request timeout (seconds)" : "Tiemo de vida de la solicitud (segundos)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "El soporte para cURL en PHP no se encuentra habilitado o instalado. El montaje de %s no es posible. Favor de solicitar a su administador su instalación. ",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "El soporte para FTP en PHP no se encuentra habilitado o instalado. El montaje de %s no es posible. Favor de solicitar a su administador su instalación. ",
    "External storage" : "Almacenamiento externo",
    "External storage support" : "Soporte de almacenamiento externo",
    "External mount error" : "Error de montaje externo",
    "Storage type" : "Tipo de almacenamiento",
    "Unknown" : "Desconocido",
    "Scope" : "Alcance",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Open documentation" : "Abrir documentación",
    "Folder name" : "Nombre de la carpeta",
    "Authentication" : "Autenticación",
    "Configuration" : "Configuración",
    "Available for" : "Disponible para",
    "Add storage" : "Agregar almacenamiento",
    "Advanced settings" : "Configuraciones avanzadas",
    "Allow users to mount external storage" : "Permitir a los usuarios montar almacenamiento externo",
    "Empty response from the server" : "Respuesta vacía del servidor",
    "Couldn't get the information from the remote server: {code} {type}" : "No fue posible obtener la información del servidor remoto: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "No fue posible obtener la lista de puntos de montaje externos: {type}",
    "There was an error with message: " : "Se presentó un problema con el mensaje:",
    "external-storage" : "almacenamiento externo",
    "Please enter the credentials for the {mount} mount" : "Favor de ingresar las credenciales para el montaje {mount}",
    "Credentials saved" : "Credenciales guardadas",
    "Credentials saving failed" : "Se ha presentado una falla al guardar las credenciales",
    "Credentials required" : "Se requieren credenciales",
    "Name" : "Nombre"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> php82-nextcloud-30.0.5.tgz: share/nextcloud/apps/files_external/l10n/es_AR.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Conceder acceso",
    "Error configuring OAuth1" : "Se presentó un error al configurar OAuth1",
    "Please provide a valid app key and secret." : "Favor de proporcionar una llave de aplicación y secreto válidos.",
    "Error configuring OAuth2" : "Se presentó un error al configurar OAuth2",
    "Generate keys" : "Generar llaves",
    "Error generating key pair" : "Se presentó un error al generar el juego de llaves",
    "Storage with ID \"%d\" not found" : "El almacenamiento con ID \"%d\" no fue encontrado",
    "Invalid backend or authentication mechanism class" : "Backend o clase de mecanismo de autenticación inválido ",
    "Invalid mount point" : "Punto de montaje inválido",
    "Objectstore forbidden" : "Objectstore prohibido",
    "Invalid storage backend \"%s\"" : "Almacenamiento de backend \"%s\" inválido ",
    "Not permitted to use backend \"%s\"" : "No está permitido usar el backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "No está permitido el uso del mecanismo de autenticación \"%s\"",
    "Unsatisfied backend parameters" : "Parametros del backend no satisfechos",
    "Unsatisfied authentication mechanism parameters" : "Parametros no satisfechos del mecanismo de autenticación",
    "Insufficient data: %s" : "Datos insuficientes: %s",
    "%s" : "%s",
    "Access key" : "Llave de acceso",
    "Secret key" : "Llave secreta",
    "Builtin" : "Integrado",
    "None" : "Ninguno",
    "OAuth1" : "OAuth1",
    "App key" : "Llave de la aplicación",
    "App secret" : "Secreto de la aplicación",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID del cliente",
    "Client secret" : "Secreto del cliente",
    "Login" : "Inicio de sesión",
    "Password" : "Contraseña",
    "Tenant name" : "¡No se encontraron archivos en su búsqueda que hayan sido modificados\n\n en los últimos 7 días! ",
    "Identity endpoint URL" : "URL del punto de enlace de Identidad",
    "Domain" : "Dominio",
    "Rackspace" : "Rackspace",
    "API key" : "Llave de API",
    "Global credentials" : "Credenciales globales",
    "Log-in credentials, save in database" : "Credenciales de inicio de sesión, guardar en la base de datos",
    "Log-in credentials, save in session" : "Credenciales de inicio de sesión, guardar en la sesión",
    "RSA public key" : "Llave pública RSA",
    "Public key" : "Llave pública",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nombre del servidor",
    "Port" : "Puerto",
    "Region" : "Región",
    "Enable SSL" : "Habilitar SSL",
    "Enable Path Style" : "Habilitar Estilo de Ruta",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subcarpeta remota",
    "Secure https://" : "https:// seguro",
    "FTP" : "FTP",
    "Host" : "Servidor",
    "Secure ftps://" : "ftps:// seguro",
    "Local" : "Local",
    "Location" : "Ubicación",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Raíz",
    "SFTP with secret key login" : "Inicio de sesión SFTP con llave secreta",
    "Share" : "Compartir",
    "Show hidden files" : "Mostrar archivos ocultos",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nombre del servicio",
    "Request timeout (seconds)" : "Tiemo de vida de la solicitud (segundos)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "El soporte para cURL en PHP no se encuentra habilitado o instalado. El montaje de %s no es posible. Favor de solicitar a su administador su instalación. ",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "El soporte para FTP en PHP no se encuentra habilitado o instalado. El montaje de %s no es posible. Favor de solicitar a su administador su instalación. ",
    "External storage" : "Almacenamiento externo",
    "External storage support" : "Soporte de almacenamiento externo",
    "Submit" : "Enviar",
    "External mount error" : "Error de montaje externo",
    "Storage type" : "Tipo de almacenamiento",
    "Unknown" : "Desconocido",
    "Scope" : "Alcance",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilidad con codificación Mac NFD (lenta)",
    "Enable encryption" : "Habilitar encripción",
    "Enable previews" : "Habilitar vistas previas",
    "Enable sharing" : "Habilitar compartir",
    "Check for changes" : "Verificar si hay cambios",
    "Never" : "Nunca",
    "Once every direct access" : "Una vez cada acceso directo",
    "Read only" : "Solo lectura",
    "Disconnect" : "Desconectar",
    "Admin defined" : "Administrador definido",
    "Saved" : "Guardado",
    "Save" : "Guardar",
    "Open documentation" : "Abrir documentación",
    "Folder name" : "Nombre de la carpeta",
    "Authentication" : "Autenticación",
    "Configuration" : "Configuración",
    "Available for" : "Disponible para",
    "Add storage" : "Agregar almacenamiento",
    "Advanced settings" : "Configuraciones avanzadas",
    "Storage with ID \"%d\" is not user editable" : "El almacenamiento con ID \"%d\" no puede ser editado por el usuario",
    "Username" : "Nombre de usuario",
    "Username and password" : "Nombre de usuario y contraseña",
    "User entered, store in database" : "Usuario ingresado, almacenar en la base de datos",
    "Username as share" : "Nombre de usuario como elemento compartido",
    "Allow users to mount external storage" : "Permitir a los usuarios montar almacenamiento externo"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
